@@ -9,13 +9,14 @@ import hippo
 
 from ddm import DataModel
 import bigboard.globals as globals
-from bigboard.slideout import ThemedSlideout
+from bigboard.slideout import Slideout
 import bigboard.libbig as libbig
 from bigboard.libbig.logutil import log_except
 from bigboard.workboard import WorkBoard
 from bigboard.stock import Stock, AbstractMugshotStock
 from bigboard.big_widgets import CanvasMugshotURLImage, PhotoContentItem, CanvasVBox, CanvasHBox
 from bigboard.big_widgets import ActionLink, IconLink, Separator
+from bigboard.core.search_entry import SearchEntry
 import bigboard.google
 
 import portfoliomanager
@@ -78,7 +79,7 @@ class LocalUserDisplay(CanvasVBox):
         
         self.__dispname = hippo.CanvasText(xalign=hippo.ALIGNMENT_END, text=dispname)
         self.append(self.__dispname)
-        self.__loginname = hippo.CanvasText(xalign=hippo.ALIGNMENT_END, font='10px Italic', 
+        self.__loginname = hippo.CanvasText(xalign=hippo.ALIGNMENT_END, id="local-user-name", 
                                             text=loginname) 
         attrs = pango.AttrList()
         attrs.insert(pango.AttrForeground(0x6666, 0x6666, 0x6666, 0, 0xFFFF))
@@ -88,16 +89,17 @@ class LocalUserDisplay(CanvasVBox):
 
         self.displays = displays
 
-class SelfSlideout(ThemedSlideout):
+class SelfSlideout(Slideout):
     __gsignals__ = {
         "account" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, []),                    
         "logout" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, []),
+        "shutdown" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, []),
         "sidebar-controls" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, []),
     }
     def __init__(self, stock, myself, fus=None, logger=None):
-        super(SelfSlideout, self).__init__()
+        super(SelfSlideout, self).__init__(stylesheet=stock.get_path('slideout.css'))
     
-        vbox = CanvasVBox(spacing=4, padding=4)
+        vbox = CanvasVBox(spacing=4, padding=4, classes='slideout-no-header')
         self.get_root().append(vbox)
 
         self._logger = logger
@@ -114,7 +116,7 @@ class SelfSlideout(ThemedSlideout):
         self.__personal_box_right = CanvasVBox()
         self.__personal_box.append(self.__personal_box_right, hippo.PACK_EXPAND)
         
-        self.__name = hippo.CanvasText(font="14px Bold",
+        self.__name = hippo.CanvasText(id="name",
                                        xalign=hippo.ALIGNMENT_START,
                                        yalign=hippo.ALIGNMENT_CENTER,
                                        size_mode=hippo.CANVAS_SIZE_ELLIPSIZE_END)
@@ -126,7 +128,7 @@ class SelfSlideout(ThemedSlideout):
         self.__personalization_box = CanvasVBox(spacing=2)
         vbox.append(self.__personalization_box)
         self.__personalization_box.append(hippo.CanvasText(text='Personalization',
-                                                           font='12px Bold',
+                                                           classes="menu-group",
                                                            xalign=hippo.ALIGNMENT_START))
 
         self.__mugshot_link = IconLink(img_scale_width=22, img_scale_height=22, xalign=hippo.ALIGNMENT_START)
@@ -157,7 +159,7 @@ class SelfSlideout(ThemedSlideout):
             self.__fus_users_box = CanvasVBox()
             self.__fus_box.append(self.__fus_users_box)
             
-            link = IconLink(text='Log in as Another User...', img_scale_width=22, img_scale_height=22, xalign=hippo.ALIGNMENT_START)
+            link = IconLink(text='Log in as Another User...', xalign=hippo.ALIGNMENT_START)
             link.link.connect("activated", self.__do_fus_login_other_user)
             link.img.set_property('image-name', '/usr/share/icons/gnome/22x22/apps/system-users.png')
             self.__fus_box.append(link)
@@ -167,9 +169,14 @@ class SelfSlideout(ThemedSlideout):
         self.__logout_controls_box = CanvasVBox()
         vbox.append(self.__logout_controls_box)
 
-        link = IconLink(text='Logout or Shutdown...', img_scale_width=22, img_scale_height=22, xalign=hippo.ALIGNMENT_START)
+        link = IconLink(text='Logout...', img_scale_width=22, img_scale_height=22, xalign=hippo.ALIGNMENT_START)
         link.link.connect("activated", self.__on_logout)
-        link.img.set_property('image-name', '/usr/share/icons/gnome/22x22/apps/gnome-shutdown.png')
+        link.img.set_property('image-name', 'gnome-logout')
+        self.__logout_controls_box.append(link)
+
+        link = IconLink(text='Shutdown...', img_scale_width=22, img_scale_height=22, xalign=hippo.ALIGNMENT_START)
+        link.link.connect("activated", self.__on_shutdown)
+        link.img.set_property('image-name', 'gnome-shutdown')
         self.__logout_controls_box.append(link)
 
         self.update_self(myself)
@@ -203,6 +210,10 @@ class SelfSlideout(ThemedSlideout):
         self.emit('logout')
         self.emit('close', True)
 
+    def __on_shutdown(self, l):
+        self.emit('shutdown')
+        self.emit('close', True)
+
     def __on_dbus_error(self, err):
         self._logger.exception("D-BUS error: %s", err)
 
@@ -244,7 +255,8 @@ class SelfSlideout(ThemedSlideout):
 class SelfStock(AbstractMugshotStock):
     """Shows a user's Mugshot personal information."""
     __gsignals__ = {
-        "info-loaded" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [])                  
+        "info-loaded" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, []),
+        "toggle-visible" : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [])                  
     }
     def __init__(self, *args, **kwargs):
         super(SelfStock,self).__init__(*args, **kwargs)
@@ -260,8 +272,7 @@ class SelfStock(AbstractMugshotStock):
         self._namephoto_box.set_photo(self._photo)
         
         self._namephoto_box_child = CanvasHBox()
-        self._name = hippo.CanvasText(text="Nobody", size_mode=hippo.CANVAS_SIZE_ELLIPSIZE_END)
-        self._name.set_property("font", "14px Bold")
+        self._name = hippo.CanvasText(text="Nobody", size_mode=hippo.CANVAS_SIZE_ELLIPSIZE_END, classes="name")
         self._namephoto_box_child.append(self._name)  
 
         self._bulb = hippo.CanvasImage(xalign=hippo.ALIGNMENT_END, yalign=hippo.ALIGNMENT_CENTER)
@@ -281,6 +292,11 @@ class SelfStock(AbstractMugshotStock):
         self._box.append(self._signin)
         self._signin.connect("button-press-event", lambda signin, event: self.__do_account())
 
+        self._search_entry = SearchEntry()
+        self._box.append(hippo.CanvasWidget(widget=self._search_entry))
+
+        self._add_more_button(self.__on_more_button, u"\u00bb")
+
         self.__myself = None
 
         self.info_loaded = False
@@ -324,7 +340,7 @@ class SelfStock(AbstractMugshotStock):
         except AttributeError, e:
             protocol_version = "0"
         if Version(protocol_version) > Version(COMPATIBLE_PROTOCOL_VERSION):
-            text = hippo.CanvasText(text="Upgrade required", font='14px Bold', border=1, border_color=0xFF0000FF)
+            text = hippo.CanvasText(text="Upgrade required", id="upgrade-required", border=1, border_color=0xFF0000FF)
             self._box.append(text)        
             errorbox = CanvasVBox()
             errorbox.append(hippo.CanvasText(text='Upgrade required'))
@@ -351,6 +367,12 @@ class SelfStock(AbstractMugshotStock):
         myself.connect(self.__on_self_changed)
         self.__on_self_changed(myself)
         self.__info_now_loaded()
+
+    def set_panel_visible(self, panel_visible):
+        self.more_button_text = u"\u00ab" if panel_visible else u"\u00bb"
+
+    def __on_more_button(self):
+        self.emit("toggle_visible")
         
     def __do_slideout(self, slideout, widget=None):
         widget_src = widget or self._box
@@ -358,17 +380,25 @@ class SelfStock(AbstractMugshotStock):
         (src_x, src_y) = widget_src.get_context().translate_to_screen(widget_src)
         slideout.slideout_from(box_x + self._box.get_allocation()[0] + 4, src_y)
         slideout.set_size_request(200, -1)
+
+    def __get_session_manager(self):
+        bus = dbus.SessionBus()
+        return bus.get_object('org.gnome.SessionManager', '/org/gnome/SessionManager')
          
     def __do_logout(self):
         self._panel.action_taken()
-        self._panel.Logout()
+        self.__get_session_manager().Logout(0)
+
+    def __do_shutdown(self):
+        self._panel.action_taken()
+        self.__get_session_manager().Shutdown()
 
     def __do_sidebar_controls(self):
         # Don't call this here; this ensures that we keep the sidebar visible while
         # stocks are being manipulated
         #self._panel.action_taken()        
         if not self.__portfolio_manager:
-            self.__portfolio_manager = portfoliomanager.PortfolioManager(self._panel)
+            self.__portfolio_manager = portfoliomanager.PortfolioManager(self)
         self.__portfolio_manager.present()
     
     def __do_account(self):
@@ -385,16 +415,19 @@ class SelfStock(AbstractMugshotStock):
             self.__last_slideout_event_time = gtk.get_current_event_time() 
             self.__slideout.destroy()
             self.__slideout = None
+            self._set_active(False)
             return
 
         if self.__last_slideout_event_time == gtk.get_current_event_time():
             return 
 
         self.__create_fus_proxy()
+        self._set_active(True)
         self.__slideout = SelfSlideout(self, self.__myself, fus=self.__fus_service, logger=_logger)
         self.__slideout.connect('account', lambda s: self.__do_account())        
         self.__slideout.connect('sidebar-controls', lambda s: self.__do_sidebar_controls())
         self.__slideout.connect('logout', lambda s: self.__do_logout())
+        self.__slideout.connect('shutdown', lambda s: self.__do_shutdown())
         self.__slideout.connect('close', lambda s, a: self.__on_activate())
         self.__do_slideout(self.__slideout)
         
@@ -407,6 +440,9 @@ class SelfStock(AbstractMugshotStock):
     def set_size(self, size):
         super(SelfStock, self).set_size(size)
         self._namephoto_box.set_size(size)
+
+    def focus_search(self):
+        self._search_entry.grab_focus()
     
     def __on_self_changed(self, myself):
         _logger.debug("self (%s) changed", myself.resource_id)
